#!/usr/bin/env python3

# The MIT License (MIT)
#
# Copyright (c) 2016 Benedikt Schmitt
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.

"""
jsonapi.tornado
===============

The *py-jsonapi* extension for tornado. Binding the API to a tornado application
is as simple as:

.. code-block:: python3

    import tornado
    import tornado.web
    import jsonapi
    import jsonapi.tornado

    app = tornado.web.Application()
    api = jsonapi.tornado.TornadoAPI("/api", db=..., tornado_app=app)

    # If the tornado application is not available, when you create the API,
    # you can bind it later:
    api.init_app(app)

The API instance is added to the tornado application's settings dictionary:

.. code-block:: python3

    assert app.settings["jsonapi"] is api

API
---

.. autoclass:: TornadoAPI
"""

# local
from .api import TornadoAPI
